@@ -3,7 +3,6 @@ import convertible
 import inspect
 import traceback
 
-
 def call(func, kwargs):
     argspec = inspect.getargspec(func)
     params = kwargs
@@ -16,8 +15,10 @@ def call(func, kwargs):
 
 
 def respond(result, message=None, success=True):
+    convertible.pretty_print()
     response = dict(success=success, message=message, data=result)
     response_json = convertible.to_json(response)
+    convertible.ugly_print()
     print(response_json)
 
 
